# -*- encoding: utf-8 -*-
# frozen_string_literal: true
# This file generated automatically using rdf vocabulary format from http://purl.org/dcx/lrmi-terms/
require 'rdf'
module RDF::Vocab
  LRMI = Class.new(RDF::Vocabulary("http://purl.org/dcx/lrmi-terms/")) do

    # Ontology definition
    ontology :"http://purl.org/dcx/lrmi-terms/",
      "http://purl.org/dc/terms/creator": "LRMI Task Group".freeze,
      "http://purl.org/dc/terms/description": "The LRMI specification is a collection of classes and properties for markup and description of educational resources. The specification builds on the extensive vocabulary provided by Schema.org and other standards. Note: the labels provided here are not considered normative.".freeze,
      "http://purl.org/dc/terms/identifier": "http://dublincore.org/dcx/lrmi-terms/".freeze,
      "http://purl.org/dc/terms/isVersionOf": "http://purl.org/dcx/lrmi-terms/1.1/".freeze,
      "http://purl.org/dc/terms/issued": "2015-02-09".freeze,
      "http://purl.org/dc/terms/license": "https://creativecommons.org/licenses/by/4.0/".freeze,
      "http://purl.org/dc/terms/title": "LRMI RDF Specification".freeze,
      "http://www.w3.org/2004/02/skos/core#historyNote": "2020-11-12: changes made reflecting developments in schema.org: added class LearningResource; added properties assesses, educationalLevel, teaches; fixed error in domain of timerequired; updated label and definition of isBasedOnUrl; skos:scopeNote used instead of dcterms:description for additional non-normative information; note added that rdfs:label is not considered normative; rangeIncludes statements updated to include skos:Concept for terms where there is an LRMI Concept Scheme or that reference a competence.".freeze

    # Class definitions
    term :AlignmentObject,
      comment: "An intangible item that describes an alignment between a learning resource and a node in an educational framework.".freeze,
      equivalentClass: "http://schema.org/AlignmentObject".freeze,
      "http://purl.org/dc/terms/issued": "2015-02-09".freeze,
      "http://www.w3.org/2004/02/skos/core#changeNote": "2020-11-12: Added scopeNote".freeze,
      "http://www.w3.org/2004/02/skos/core#scopeNote": "This class should not be used where the nature of the alignment can be described using a simple property, for example to express that a resource teaches or assesses a competency.".freeze,
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/".freeze,
      label: "Alignment Object".freeze,
      subClassOf: "http://schema.org/Intangible".freeze,
      type: "http://www.w3.org/2000/01/rdf-schema#Class".freeze
    term :EducationalAudience,
      comment: "An individual or group for whom the learning resource was created or useful.".freeze,
      equivalentClass: "http://schema.org/EducationalAudience".freeze,
      "http://purl.org/dc/terms/issued": "2015-02-09".freeze,
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/".freeze,
      label: "Educational Audience".freeze,
      subClassOf: "http://schema.org/Intangible".freeze,
      type: "http://www.w3.org/2000/01/rdf-schema#Class".freeze
    term :LearningResource,
      comment: "A persistent resource that has one or more physical or digital representations, and that explicitly involves, specifies or entails a learning activity or learning experience.".freeze,
      equivalentClass: "http://schema.org/LearningResource".freeze,
      "http://purl.org/dc/terms/issued": "2020-11-12".freeze,
      "http://www.w3.org/2004/02/skos/core#scopeNote": "LearningResource is expected to be used as an addition to a primary type such as http://purl.org/ontology/bibo/Book, https://schema.org/Video, http://purl.org/dc/terms/PhysicalResource etc.".freeze,
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/".freeze,
      label: "Learning Resource".freeze,
      subClassOf: "http://schema.org/CreativeWork".freeze,
      type: "http://www.w3.org/2000/01/rdf-schema#Class".freeze

    # Property definitions
    property :alignmentType,
      comment: "A category of alignment between the learning resource and the framework node.".freeze,
      domainIncludes: ["http://purl.org/dcx/lrmi-terms/AlignmentObject".freeze, "http://schema.org/AlignmentObject".freeze],
      equivalentProperty: "http://schema.org/alignmentType".freeze,
      "http://purl.org/dc/terms/issued": "2015-02-09".freeze,
      "http://www.w3.org/2004/02/skos/core#changeNote": "2020-11-12: Added scopeNote; added skos:Concept to rangeIncludes.".freeze,
      "http://www.w3.org/2004/02/skos/core#scopeNote": "Recommended values include: 'requires', 'textComplexity', 'readingLevel', and 'educationalSubject'. For 'assesses', 'teaches', and 'educationLevel' the specific properties with those names should be used.".freeze,
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/".freeze,
      label: "Alignment Type".freeze,
      rangeIncludes: ["http://www.w3.org/2001/XMLSchema#string".freeze, "http://www.w3.org/2004/02/skos/core#Concept".freeze],
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property".freeze
    property :assesses,
      comment: "The item being described is intended to assess the competency or learning outcome defined by the referenced term.".freeze,
      domainIncludes: ["http://purl.org/dcx/lrmi-terms/LearningResource".freeze, "http://schema.org/CreativeWork".freeze, "http://schema.org/LearningResource".freeze],
      equivalentProperty: "http://schema.org/assesses".freeze,
      "http://purl.org/dc/terms/issued": "2020-11-12".freeze,
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/".freeze,
      label: "Assesses".freeze,
      rangeIncludes: ["http://schema.org/DefinedTerm".freeze, "http://www.w3.org/2004/02/skos/core#Concept".freeze],
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property".freeze
    property :educationalAlignment,
      comment: "An alignment to an established educational framework.".freeze,
      domainIncludes: ["http://purl.org/dcx/lrmi-terms/LearningResource".freeze, "http://schema.org/CreativeWork".freeze, "http://schema.org/LearningResource".freeze],
      equivalentProperty: "http://schema.org/educationalAlignment".freeze,
      "http://purl.org/dc/terms/issued": "2015-02-09".freeze,
      "http://www.w3.org/2004/02/skos/core#changeNote": "2020-11-12: added lrmi:LearningResource, schema:LearningResource to domain; added scopeNote".freeze,
      "http://www.w3.org/2004/02/skos/core#scopeNote": "This property should not be used where the nature of the alignment can be described using a simple property, for example to express that a resource teaches or assesses a competency.".freeze,
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/".freeze,
      label: "Educational Alignment".freeze,
      rangeIncludes: ["http://purl.org/dcx/lrmi-terms/AlignmentObject".freeze, "http://schema.org/AlignmentObject".freeze],
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property".freeze
    property :educationalFramework,
      comment: "The framework to which the resource being described is aligned.".freeze,
      domainIncludes: ["http://purl.org/dcx/lrmi-terms/AlignmentObject".freeze, "http://schema.org/AlignmentObject".freeze],
      equivalentProperty: "http://schema.org/educationalFramework".freeze,
      "http://purl.org/dc/terms/issued": "2015-02-09".freeze,
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/".freeze,
      label: "Educational Framework".freeze,
      rangeIncludes: "http://www.w3.org/2001/XMLSchema#string".freeze,
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property".freeze
    property :educationalLevel,
      comment: "The level of a resource in terms of progression through an educational or training context.".freeze,
      domainIncludes: ["http://purl.org/dcx/lrmi-terms/LearningResource".freeze, "http://schema.org/CreativeWork".freeze, "http://schema.org/LearningResource".freeze],
      equivalentProperty: "http://schema.org/assesses".freeze,
      "http://purl.org/dc/terms/issued": "2020-11-12".freeze,
      "http://www.w3.org/2004/02/skos/core#scopeNote": "Examples of educational levels include 'beginner', 'intermediate' or 'advanced', and formal sets of level indicators.".freeze,
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/".freeze,
      label: "Educational Level".freeze,
      rangeIncludes: ["http://schema.org/DefinedTerm".freeze, "http://www.w3.org/2004/02/skos/core#Concept".freeze],
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property".freeze
    property :educationalRole,
      comment: "The role that describes the target audience of the content.".freeze,
      domainIncludes: ["http://purl.org/dcx/lrmi-terms/EducationalAudience".freeze, "http://schema.org/EducationalAudience".freeze],
      equivalentProperty: "http://schema.org/educationalRole".freeze,
      "http://purl.org/dc/terms/issued": "2015-02-09".freeze,
      "http://www.w3.org/2004/02/skos/core#changeNote": "2020-11-12: Added skos:Concept to rangeIncludes".freeze,
      "http://www.w3.org/2004/02/skos/core#scopeNote": "The educational function assumed or part played by the group for whom the resource is intended.".freeze,
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/".freeze,
      label: "Educational Role".freeze,
      rangeIncludes: ["http://www.w3.org/2001/XMLSchema#string".freeze, "http://www.w3.org/2004/02/skos/core#Concept".freeze],
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property".freeze
    property :educationalUse,
      comment: "The purpose of a work in the context of education.".freeze,
      domainIncludes: ["http://purl.org/dcx/lrmi-terms/LearningResource".freeze, "http://schema.org/CreativeWork".freeze, "http://schema.org/LearningResource".freeze],
      equivalentProperty: ["http://schema.org/educationalUse".freeze, "http://www.w3.org/2004/02/skos/core#Concept".freeze],
      "http://purl.org/dc/terms/issued": "2015-02-09".freeze,
      "http://www.w3.org/2004/02/skos/core#changeNote": "2020-11-12: added lrmi:LearningResource, schema:LearningResource to domain; added skos:Concept to rangeIncludes".freeze,
      "http://www.w3.org/2004/02/skos/core#scopeNote": "For example, 'assignment', 'group work'.".freeze,
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/".freeze,
      label: "Educational Use".freeze,
      rangeIncludes: "http://www.w3.org/2001/XMLSchema#string".freeze,
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property".freeze
    property :interactivityType,
      comment: "The predominant mode of learning supported by the learning resource.".freeze,
      domainIncludes: ["http://purl.org/dcx/lrmi-terms/LearningResource".freeze, "http://schema.org/CreativeWork".freeze, "http://schema.org/LearningResource".freeze],
      equivalentProperty: "http://schema.org/interactivityType".freeze,
      "http://purl.org/dc/terms/issued": "2015-02-09".freeze,
      "http://www.w3.org/2004/02/skos/core#changeNote": "2020-11-12: added lrmi:LearningResource, schema:LearningResource to domain; added skos:Concept to rangeIncludes".freeze,
      "http://www.w3.org/2004/02/skos/core#scopeNote": ["Acceptable values are 'active', 'expositive', or 'mixed'.".freeze, "Based on, and mappable from, IEEE LOM 5.1: Interactivity Type.".freeze],
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/".freeze,
      label: "Interactivity Type".freeze,
      rangeIncludes: ["http://www.w3.org/2001/XMLSchema#string".freeze, "http://www.w3.org/2004/02/skos/core#Concept".freeze],
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property".freeze
    property :isBasedOnUrl,
      comment: "A resource from which this work is derived or from which it is a modification or adaption.".freeze,
      domainIncludes: "http://schema.org/CreativeWork".freeze,
      equivalentProperty: ["http://schema.org/isBasedOn".freeze, "http://schema.org/isBasedOnUrl".freeze],
      "http://purl.org/dc/terms/issued": "2015-02-09".freeze,
      "http://www.w3.org/2004/02/skos/core#scopeNote": "This term can be repeated for multiple sources.".freeze,
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/".freeze,
      label: "Is Based On".freeze,
      rangeIncludes: "http://www.w3.org/2001/XMLSchema#anyURI".freeze,
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property".freeze
    property :learningResourceType,
      comment: "The predominant type or kind characterizing the learning resource.".freeze,
      domainIncludes: ["http://purl.org/dcx/lrmi-terms/LearningResource".freeze, "http://schema.org/CreativeWork".freeze, "http://schema.org/LearningResource".freeze],
      equivalentProperty: "http://schema.org/learningResourceType".freeze,
      "http://purl.org/dc/terms/issued": "2015-02-09".freeze,
      "http://www.w3.org/2004/02/skos/core#changeNote": "2020-11-12: added lrmi:LearningResource, schema:LearningResource to domain".freeze,
      "http://www.w3.org/2004/02/skos/core#scopeNote": "For example, 'presentation', 'handout'.".freeze,
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/".freeze,
      label: "Learning Resource Type".freeze,
      rangeIncludes: "http://www.w3.org/2001/XMLSchema#string".freeze,
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property".freeze
    property :targetDescription,
      comment: "The description of a node in an established educational framework.".freeze,
      domainIncludes: ["http://purl.org/dcx/lrmi-terms/AlignmentObject".freeze, "http://schema.org/AlignmentObject".freeze],
      equivalentProperty: "http://schema.org/targetDescription".freeze,
      "http://purl.org/dc/terms/issued": "2015-02-09".freeze,
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/".freeze,
      label: "Target Description".freeze,
      rangeIncludes: "http://www.w3.org/2001/XMLSchema#string".freeze,
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property".freeze
    property :targetName,
      comment: "The name of a node in an established educational framework.".freeze,
      domainIncludes: ["http://purl.org/dcx/lrmi-terms/AlignmentObject".freeze, "http://schema.org/AlignmentObject".freeze],
      equivalentProperty: "http://schema.org/targetName".freeze,
      "http://purl.org/dc/terms/issued": "2015-02-09".freeze,
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/".freeze,
      label: "Target Name".freeze,
      rangeIncludes: "http://www.w3.org/2001/XMLSchema#string".freeze,
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property".freeze
    property :targetUrl,
      comment: "The URL of a node in an established educational framework.".freeze,
      domainIncludes: ["http://purl.org/dcx/lrmi-terms/AlignmentObject".freeze, "http://schema.org/AlignmentObject".freeze],
      equivalentProperty: "http://schema.org/targetUrl".freeze,
      "http://purl.org/dc/terms/issued": "2015-02-09".freeze,
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/".freeze,
      label: "Target URL".freeze,
      rangeIncludes: "http://www.w3.org/2001/XMLSchema#anyURI".freeze,
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property".freeze
    property :teaches,
      comment: "The item being described is intended to help a person learn the competency or learning outcome defined by the referenced term.".freeze,
      domainIncludes: ["http://purl.org/dcx/lrmi-terms/LearningResource".freeze, "http://schema.org/CreativeWork".freeze, "http://schema.org/LearningResource".freeze],
      equivalentProperty: "http://schema.org/teaches".freeze,
      "http://purl.org/dc/terms/issued": "2020-11-12".freeze,
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/".freeze,
      label: "Teaches".freeze,
      rangeIncludes: ["http://schema.org/DefinedTerm".freeze, "http://www.w3.org/2004/02/skos/core#Concept".freeze],
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property".freeze
    property :timeRequired,
      comment: "Approximate or typical time it takes to work with or through this learning resource for the typical intended target audience.".freeze,
      domainIncludes: "http://schema.org/CreativeWork".freeze,
      equivalentProperty: "http://schema.org/timeRequired".freeze,
      "http://purl.org/dc/terms/issued": "2015-02-09".freeze,
      "http://www.w3.org/2004/02/skos/core#changeNote": "2020-11-12: error in domain fixed, changed from lrmi:AlignmentObject to schema:CreativeWork".freeze,
      "http://www.w3.org/2004/02/skos/core#scopeNote": ["Based on, and mappable from, IEEE LOM 5.9: Typical Learning   Time.".freeze, "For example, 'PT30M' and 'PT1H25M'".freeze],
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/".freeze,
      label: "Time Required".freeze,
      rangeIncludes: "http://schema.org/Duration".freeze,
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property".freeze
    property :typicalAgeRange,
      comment: "The typical expected age range.".freeze,
      domainIncludes: "http://schema.org/CreativeWork".freeze,
      equivalentProperty: "http://schema.org/typicalAgeRange".freeze,
      "http://purl.org/dc/terms/issued": "2015-02-09".freeze,
      "http://www.w3.org/2004/02/skos/core#scopeNote": ["Based on, and mappable from, IEEE LOM 5.7: Typical Age Range.".freeze, "For example, '7-9', '18-'.".freeze],
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/".freeze,
      label: "Typical Age Range".freeze,
      rangeIncludes: "http://www.w3.org/2001/XMLSchema#string".freeze,
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property".freeze
    property :useRightsUrl,
      comment: "The URL where the owner specifies permissions for using the   resource.".freeze,
      domainIncludes: "http://schema.org/CreativeWork".freeze,
      "http://purl.org/dc/terms/issued": "2015-02-09".freeze,
      "http://www.w3.org/2004/02/skos/core#scopeNote": "For example: 'http://creativecommons.org/licenses/by/3.0/',\n   'http://publisher.com/content-use-description'.".freeze,
      isDefinedBy: "http://purl.org/dcx/lrmi-terms/".freeze,
      label: "Use Rights URL".freeze,
      rangeIncludes: ["http://schema.org/CreativeWork".freeze, "http://www.w3.org/2001/XMLSchema#anyURI".freeze],
      subPropertyOf: "http://schema.org/license".freeze,
      type: "http://www.w3.org/1999/02/22-rdf-syntax-ns#Property".freeze
  end
end
